@@ -4,7 +4,7 @@ use warnings;
 
 package HTTP::CookieJar;
 # ABSTRACT: A minimalist HTTP user agent cookie jar
-our $VERSION = '0.011'; # TRIAL
+our $VERSION = '0.013'; # TRIAL
 
 use Carp       ();
 use HTTP::Date ();
@@ -124,8 +124,8 @@ sub clear {
 #pod * secure -- if present, the cookie was set C<Secure>
 #pod * httponly -- if present, the cookie was set C<HttpOnly>
 #pod * hostonly -- if present, the cookie may only be used with the domain as a host
-#pod * creation_time -- epoch seconds since the cookie was first stored
-#pod * last_access_time -- epoch seconds since the cookie was last stored
+#pod * creation_time -- epoch time when the cookie was first stored
+#pod * last_access_time -- epoch time when the cookie was last accessed (i.e. "now")
 #pod
 #pod Keep in mind that C<httponly> means it should only be used in requests and not
 #pod made available via Javascript, etc.  This is pretty meaningless for Perl user
@@ -138,6 +138,13 @@ sub clear {
 #pod =cut
 
 sub cookies_for {
+    my ( $self, $request ) = @_;
+    my @found = $self->_cookies_for($request);
+    return map { {%$_} } @found;
+}
+
+# _cookies_for returns originals, not copies, which helps in testing
+sub _cookies_for {
     my ( $self, $request ) = @_;
     my ( $scheme, $host, $port, $request_path ) = eval { _split_url($request) };
     Carp::croak($@) if $@;
@@ -150,6 +157,7 @@ sub cookies_for {
         next if defined( $cookie->{expires} ) && $cookie->{expires} < $now;
         next unless _domain_match( $host, $cookie->{domain} );
         next unless _path_match( $request_path, $cookie->{path} );
+        $cookie->{last_access_time} = time;
         push @found, $cookie;
     }
     @found = sort {
@@ -256,11 +264,9 @@ sub load_cookies {
 # private methods
 #--------------------------------------------------------------------------#
 
-# return a copy of all cookies
+# return flattened list of all cookies
 sub _all_cookies {
-    return map {
-        { %$_ }
-    } map { values %$_ } map { values %$_ } values %{ $_[0]->{store} };
+    return map { values %$_ } map { values %$_ } values %{ $_[0]->{store} };
 }
 
 #--------------------------------------------------------------------------#
@@ -388,7 +394,7 @@ HTTP::CookieJar - A minimalist HTTP user agent cookie jar
 
 =head1 VERSION
 
-version 0.011
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -490,11 +496,11 @@ hostonly -- if present, the cookie may only be used with the domain as a host
 
 =item *
 
-creation_time -- epoch seconds since the cookie was first stored
+creation_time -- epoch time when the cookie was first stored
 
 =item *
 
-last_access_time -- epoch seconds since the cookie was last stored
+last_access_time -- epoch time when the cookie was last accessed (i.e. "now")
 
 =back
 
